@@ -378,13 +378,18 @@ class FocusRenderer(BaseRenderer):
     A Renderer that takes an image and randomly spreads the characters around the screen.
     The characters are then pulled to the middle of the screen
     """
-    def __init__(self, screen, frames, time, img, effect_type="static", background=" ", transparent=False, start_frame=0, reverse=False):
+    def __init__(self, screen, frames, time, img, effect_type="static", background=" ", transparent=False, start_frame=0, reverse=False, start_reverse=None):
         super(FocusRenderer, self).__init__(screen, frames, time, effect_type, background, transparent)
         self.background        = background if background else " "
         self.transparent       = transparent if transparent else False
         self.img               = img
         self.start_frame       = start_frame
         self.reverse           = reverse
+        self.start_reverse     = start_reverse
+
+        if self.reverse and self.start_reverse == None:
+            raise Exception("if reverse is enabled, and start_reverse frame must be provided")
+
         if self.img: self._set_img_attributes()
 
     def _set_img_attributes(self):
@@ -410,12 +415,13 @@ class FocusRenderer(BaseRenderer):
                                   -1 if (self.end_board[y][x][1] - self.current_board[y][x][1]) < 0 else 1]
                                   for x in range(self.img_width)] for y in range(self.img_height)]
 
-    def update_reverse(self, reverse):
+    def update_reverse(self, reverse, start_reverse):
         """
         Function to update whether or not to reverse the Focus
         :param reverse: True / False
         """
-        self.reverse = reverse
+        self.reverse       = reverse
+        self.start_reverse = start_reverse
 
     def update_start_frame(self, frame_number):
         """
